@@ -5,10 +5,8 @@ from django.conf.urls.i18n import i18n_patterns
 from seo.views import sitemap_download, sitemap_tree
 
 
-seo_urlpatterns = [
+app_urls = [
     path('sitemap.xml', sitemap_download)
-]
-
-seo_urlpatterns += i18n_patterns(
+] + i18n_patterns(
     path('sitemap/', sitemap_tree, name='sitemap-tree'),
 )
